@@ -121,6 +121,10 @@ static ValidProperty valid_properties[] = {
 	{ NM_OPENVPN_KEY_TLS_REMOTE,	       G_TYPE_STRING, 0, 0, FALSE },
 	{ NM_OPENVPN_KEY_TUNNEL_MTU,           G_TYPE_INT, 0, G_MAXINT, FALSE },
 	{ NM_OPENVPN_KEY_USERNAME,             G_TYPE_STRING, 0, 0, FALSE },
+	{ NM_OPENVPN_KEY_PASSWORD"-flags",     G_TYPE_STRING, 0, 0, FALSE },
+	{ NM_OPENVPN_KEY_CERTPASS"-flags",     G_TYPE_STRING, 0, 0, FALSE },
+	{ NM_OPENVPN_KEY_NOSECRET,             G_TYPE_STRING, 0, 0, FALSE },
+	{ NM_OPENVPN_KEY_HTTP_PROXY_PASSWORD"-flags", G_TYPE_STRING, 0, 0, FALSE },
 	{ NULL,                                G_TYPE_NONE, FALSE }
 };
 
@@ -185,7 +189,7 @@ validate_one_property (const char *key, const char *value, gpointer user_data)
 			g_set_error (info->error,
 			             NM_VPN_PLUGIN_ERROR,
 			             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
-			             "invalid address '%s'",
+			             _("invalid address '%s'"),
 			             key);
 			break;
 		case G_TYPE_INT:
@@ -197,7 +201,7 @@ validate_one_property (const char *key, const char *value, gpointer user_data)
 			g_set_error (info->error,
 			             NM_VPN_PLUGIN_ERROR,
 			             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
-			             "invalid integer property '%s' or out of range [%d -> %d]",
+			             _("invalid integer property '%s' or out of range [%d -> %d]"),
 			             key, prop.int_min, prop.int_max);
 			break;
 		case G_TYPE_BOOLEAN:
@@ -207,14 +211,14 @@ validate_one_property (const char *key, const char *value, gpointer user_data)
 			g_set_error (info->error,
 			             NM_VPN_PLUGIN_ERROR,
 			             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
-			             "invalid boolean property '%s' (not yes or no)",
+			             _("invalid boolean property '%s' (not yes or no)"),
 			             key);
 			break;
 		default:
 			g_set_error (info->error,
 			             NM_VPN_PLUGIN_ERROR,
 			             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
-			             "unhandled property '%s' type %s",
+			             _("unhandled property '%s' type %s"),
 			             key, g_type_name (prop.type));
 			break;
 		}
@@ -225,7 +229,7 @@ validate_one_property (const char *key, const char *value, gpointer user_data)
 		g_set_error (info->error,
 		             NM_VPN_PLUGIN_ERROR,
 		             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
-		             "property '%s' invalid or not supported",
+		             _("property '%s' invalid or not supported"),
 		             key);
 	}
 }
@@ -242,7 +246,7 @@ nm_openvpn_properties_validate (NMSettingVPN *s_vpn, GError **error)
 		             NM_VPN_PLUGIN_ERROR,
 		             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
 		             "%s",
-		             "No VPN configuration options.");
+		             _("No VPN configuration options."));
 		return FALSE;
 	}
 
@@ -265,7 +269,7 @@ nm_openvpn_secrets_validate (NMSettingVPN *s_vpn, GError **error)
 		             NM_VPN_PLUGIN_ERROR,
 		             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
 		             "%s",
-		             "No VPN secrets!");
+		             _("No VPN secrets!"));
 		return FALSE;
 	}
 
@@ -414,7 +418,7 @@ handle_management_socket (NMVPNPlugin *plugin,
 			if (io_data->username != NULL && io_data->password != NULL)
 				write_user_pass (source, auth, io_data->username, io_data->password);
 			else
-				nm_warning ("Auth requested but one of username or password is missing");
+				g_warning ("Auth requested but one of username or password is missing");
 		} else if (!strcmp (auth, "Private Key")) {
 			if (io_data->priv_key_pass) {
 				char *qpass;
@@ -430,14 +434,14 @@ handle_management_socket (NMVPNPlugin *plugin,
 				g_io_channel_flush (source, NULL);
 				g_free (buf);
 			} else
-				nm_warning ("Certificate password requested but private key password == NULL");
+				g_warning ("Certificate password requested but private key password == NULL");
 		} else if (strcmp (auth, "HTTP Proxy") == 0) {
 			if (io_data->proxy_username != NULL && io_data->proxy_password != NULL)
 				write_user_pass (source, auth, io_data->proxy_username, io_data->proxy_password);
 			else
-				nm_warning ("HTTP Proxy auth requested but either proxy username or password is missing");
+				g_warning ("HTTP Proxy auth requested but either proxy username or password is missing");
 		} else {
-			nm_warning ("No clue what to send for username/password request for '%s'", auth);
+			g_warning ("No clue what to send for username/password request for '%s'", auth);
 			if (out_failure)
 				*out_failure = NM_VPN_PLUGIN_FAILURE_CONNECT_FAILED;
 			again = FALSE;
@@ -448,11 +452,11 @@ handle_management_socket (NMVPNPlugin *plugin,
 	auth = get_detail (str, ">PASSWORD:Verification Failed: '");
 	if (auth) {
 		if (!strcmp (auth, "Auth"))
-			nm_warning ("Password verification failed");
+			g_warning ("Password verification failed");
 		else if (!strcmp (auth, "Private Key"))
-			nm_warning ("Private key verification failed");
+			g_warning ("Private key verification failed");
 		else
-			nm_warning ("Unknown verification failed: %s", auth);
+			g_warning ("Unknown verification failed: %s", auth);
 
 		g_free (auth);
 
@@ -500,7 +504,7 @@ nm_openvpn_connect_timer_cb (gpointer data)
 
 	serv_addr.sin_family = AF_INET;
 	if (inet_pton (AF_INET, "127.0.0.1", &(serv_addr.sin_addr)) <= 0)
-		nm_warning ("%s: could not convert 127.0.0.1", __func__);
+		g_warning ("%s: could not convert 127.0.0.1", __func__);
 	serv_addr.sin_port = htons (1194);
  
 	connected = (connect (socket_fd, (struct sockaddr *) &serv_addr, sizeof (serv_addr)) == 0);
@@ -511,7 +515,7 @@ nm_openvpn_connect_timer_cb (gpointer data)
 
 		priv->connect_timer = 0;
 
-		nm_warning ("Could not open management socket");
+		g_warning ("Could not open management socket");
 		nm_vpn_plugin_failure (NM_VPN_PLUGIN (plugin), NM_VPN_PLUGIN_FAILURE_CONNECT_FAILED);
 		nm_vpn_plugin_set_state (NM_VPN_PLUGIN (plugin), NM_VPN_SERVICE_STATE_STOPPED);
 	} else {
@@ -554,14 +558,14 @@ openvpn_watch_cb (GPid pid, gint status, gpointer user_data)
 	if (WIFEXITED (status)) {
 		error = WEXITSTATUS (status);
 		if (error != 0)
-			nm_warning ("openvpn exited with error code %d", error);
+			g_warning ("openvpn exited with error code %d", error);
     }
 	else if (WIFSTOPPED (status))
-		nm_warning ("openvpn stopped unexpectedly with signal %d", WSTOPSIG (status));
+		g_warning ("openvpn stopped unexpectedly with signal %d", WSTOPSIG (status));
 	else if (WIFSIGNALED (status))
-		nm_warning ("openvpn died with signal %d", WTERMSIG (status));
+		g_warning ("openvpn died with signal %d", WTERMSIG (status));
 	else
-		nm_warning ("openvpn died from an unknown cause");
+		g_warning ("openvpn died from an unknown cause");
   
 	/* Reap child if needed. */
 	waitpid (priv->pid, NULL, WNOHANG);
@@ -601,7 +605,6 @@ validate_auth (const char *auth)
 {
 	if (auth) {
 		if (   !strcmp (auth, NM_OPENVPN_AUTH_NONE)
-		    || !strcmp (auth, NM_OPENVPN_AUTH_RSA_MD4)
 		    || !strcmp (auth, NM_OPENVPN_AUTH_MD5)
 		    || !strcmp (auth, NM_OPENVPN_AUTH_SHA1)
 		    || !strcmp (auth, NM_OPENVPN_AUTH_SHA224)
@@ -738,7 +741,7 @@ nm_openvpn_start_openvpn_binary (NMOpenvpnPlugin *plugin,
 		             NM_VPN_PLUGIN_ERROR,
 		             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
 		             "%s",
-		             "Could not find the openvpn binary.");
+		             _("Could not find the openvpn binary."));
 		return FALSE;
 	}
   
@@ -749,7 +752,7 @@ nm_openvpn_start_openvpn_binary (NMOpenvpnPlugin *plugin,
  			             NM_VPN_PLUGIN_ERROR,
  			             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
  			             "%s",
- 			             "Invalid HMAC auth.");
+ 			             _("Invalid HMAC auth."));
  			return FALSE;
  		}
  	}
@@ -761,7 +764,7 @@ nm_openvpn_start_openvpn_binary (NMOpenvpnPlugin *plugin,
 		             NM_VPN_PLUGIN_ERROR,
 		             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
 		             "%s",
-		             "Invalid connection type.");
+		             _("Invalid connection type."));
 		return FALSE;
 	}
 
@@ -783,7 +786,7 @@ nm_openvpn_start_openvpn_binary (NMOpenvpnPlugin *plugin,
 			add_openvpn_arg (args, "--http-proxy");
 			add_openvpn_arg (args, tmp2);
 			add_openvpn_arg (args, tmp3 ? tmp3 : "8080");
-			add_openvpn_arg (args, "auto");  /* Automatic proxy auth method detection */
+			add_openvpn_arg (args, "'auto'");  /* Automatic proxy auth method detection */
 			if (tmp4)
 				add_openvpn_arg (args, "--http-proxy-retry");
 		} else if (!strcmp (tmp, "socks")) {
@@ -796,7 +799,7 @@ nm_openvpn_start_openvpn_binary (NMOpenvpnPlugin *plugin,
 			g_set_error (error,
 				         NM_VPN_PLUGIN_ERROR,
 				         NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
-				         "Invalid proxy type '%s'.",
+				         _("Invalid proxy type '%s'."),
 				         tmp);
 			return FALSE;
 		}
@@ -832,7 +835,7 @@ nm_openvpn_start_openvpn_binary (NMOpenvpnPlugin *plugin,
 			g_set_error (error,
 			             NM_VPN_PLUGIN_ERROR,
 			             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
-			             "Invalid port number '%s'.",
+			             _("Invalid port number '%s'."),
 			             tmp);
 			free_openvpn_args (args);
 			return FALSE;
@@ -882,7 +885,7 @@ nm_openvpn_start_openvpn_binary (NMOpenvpnPlugin *plugin,
 			g_set_error (error,
 			             NM_VPN_PLUGIN_ERROR,
 			             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
-			             "Invalid reneg seconds '%s'.",
+			             _("Invalid reneg seconds '%s'."),
 			             tmp);
 			free_openvpn_args (args);
 			return FALSE;
@@ -906,7 +909,7 @@ nm_openvpn_start_openvpn_binary (NMOpenvpnPlugin *plugin,
 			g_set_error (error,
 			             NM_VPN_PLUGIN_ERROR,
 			             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
-			             "Invalid TUN MTU size '%s'.",
+			             _("Invalid TUN MTU size '%s'."),
 			             tmp);
 			free_openvpn_args (args);
 			return FALSE;
@@ -921,7 +924,7 @@ nm_openvpn_start_openvpn_binary (NMOpenvpnPlugin *plugin,
 			g_set_error (error,
 			             NM_VPN_PLUGIN_ERROR,
 			             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
-			             "Invalid fragment size '%s'.",
+			             _("Invalid fragment size '%s'."),
 			             tmp);
 			free_openvpn_args (args);
 			return FALSE;
@@ -989,7 +992,7 @@ nm_openvpn_start_openvpn_binary (NMOpenvpnPlugin *plugin,
 			             NM_VPN_PLUGIN_ERROR,
 			             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
 			             "%s",
-			             "Missing required local IP address for static key mode.");
+			             _("Missing required local IP address for static key mode."));
 			free_openvpn_args (args);
 			return FALSE;
 		}
@@ -1002,7 +1005,7 @@ nm_openvpn_start_openvpn_binary (NMOpenvpnPlugin *plugin,
 			             NM_VPN_PLUGIN_ERROR,
 			             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
 			             "%s",
-			             "Missing required remote IP address for static key mode.");
+			             _("Missing required remote IP address for static key mode."));
 			free_openvpn_args (args);
 			return FALSE;
 		}
@@ -1027,7 +1030,7 @@ nm_openvpn_start_openvpn_binary (NMOpenvpnPlugin *plugin,
 		g_set_error (error,
 		             NM_VPN_PLUGIN_ERROR,
 		             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
-		             "Unknown connection type '%s'.",
+		             _("Unknown connection type '%s'."),
 		             connection_type);
 		free_openvpn_args (args);
 		return FALSE;
@@ -1042,7 +1045,7 @@ nm_openvpn_start_openvpn_binary (NMOpenvpnPlugin *plugin,
 	}
 	free_openvpn_args (args);
 
-	nm_info ("openvpn started with pid %d", pid);
+	g_message ("openvpn started with pid %d", pid);
 
 	priv->pid = pid;
 	openvpn_watch = g_child_watch_source_new (pid);
@@ -1146,7 +1149,7 @@ real_connect (NMVPNPlugin   *plugin,
 		             NM_VPN_PLUGIN_ERROR,
 		             NM_VPN_PLUGIN_ERROR_CONNECTION_INVALID,
 		             "%s",
-		             "Could not process the request because the VPN connection settings were invalid.");
+		             _("Could not process the request because the VPN connection settings were invalid."));
 		return FALSE;
 	}
 
@@ -1157,7 +1160,7 @@ real_connect (NMVPNPlugin   *plugin,
 		             NM_VPN_PLUGIN_ERROR,
 		             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
 		             "%s",
-		             "Invalid connection type.");
+		             _("Invalid connection type."));
 		return FALSE;
 	}
 
@@ -1171,7 +1174,7 @@ real_connect (NMVPNPlugin   *plugin,
 			             NM_VPN_PLUGIN_ERROR,
 			             NM_VPN_PLUGIN_ERROR_CONNECTION_INVALID,
 			             "%s",
-			             "Could not process the request because no username was provided.");
+			             _("Could not process the request because no username was provided."));
 			return FALSE;
 		}
 	}
@@ -1206,13 +1209,18 @@ real_need_secrets (NMVPNPlugin *plugin,
 	g_return_val_if_fail (NM_IS_VPN_PLUGIN (plugin), FALSE);
 	g_return_val_if_fail (NM_IS_CONNECTION (connection), FALSE);
 
+	if (debug) {
+		g_message ("%s: connection -------------------------------------", __func__);
+		nm_connection_dump (connection);
+	}
+
 	s_vpn = NM_SETTING_VPN (nm_connection_get_setting (connection, NM_TYPE_SETTING_VPN));
 	if (!s_vpn) {
 		g_set_error (error,
 		             NM_VPN_PLUGIN_ERROR,
 		             NM_VPN_PLUGIN_ERROR_CONNECTION_INVALID,
 		             "%s",
-		             "Could not process the request because the VPN connection settings were invalid.");
+		             _("Could not process the request because the VPN connection settings were invalid."));
 		return FALSE;
 	}
 
@@ -1222,7 +1230,7 @@ real_need_secrets (NMVPNPlugin *plugin,
 		             NM_VPN_PLUGIN_ERROR,
 		             NM_VPN_PLUGIN_ERROR_BAD_ARGUMENTS,
 		             "%s",
-		             "Invalid connection type.");
+		             _("Invalid connection type."));
 		return FALSE;
 	}
 
@@ -1255,7 +1263,7 @@ real_disconnect (NMVPNPlugin	 *plugin,
 		else
 			kill (priv->pid, SIGKILL);
 
-		nm_info ("Terminated openvpn daemon with PID %d.", priv->pid);
+		g_message ("Terminated openvpn daemon with PID %d.", priv->pid);
 		priv->pid = 0;
 	}
 
@@ -1356,8 +1364,8 @@ main (int argc, char *argv[])
 	GOptionContext *opt_ctx = NULL;
 
 	GOptionEntry options[] = {
-		{ "persist", 0, 0, G_OPTION_ARG_NONE, &persist, "Don't quit when VPN connection terminates", NULL },
-		{ "debug", 0, 0, G_OPTION_ARG_NONE, &debug, "Enable verbose debug logging (may expose passwords)", NULL },
+		{ "persist", 0, 0, G_OPTION_ARG_NONE, &persist, N_("Don't quit when VPN connection terminates"), NULL },
+		{ "debug", 0, 0, G_OPTION_ARG_NONE, &debug, N_("Enable verbose debug logging (may expose passwords)"), NULL },
 		{NULL}
 	};
 
@@ -1371,7 +1379,7 @@ main (int argc, char *argv[])
 	g_option_context_add_main_entries (opt_ctx, options, NULL);
 
 	g_option_context_set_summary (opt_ctx,
-		"nm-vpnc-service provides integrated OpenVPN capability to NetworkManager.");
+		_("nm-vpnc-service provides integrated OpenVPN capability to NetworkManager."));
 
 	g_option_context_parse (opt_ctx, &argc, &argv, NULL);
 	g_option_context_free (opt_ctx);
